@@ -37,21 +37,35 @@ def fit(time_event, censoring, labx, verbose=3):
 
     Returns
     -------
-    dict: containing logrank pvalue and keys required to make plots.
+    dict()
+        * logrank_P (float) : P-value
+        * logrank_Z (float) : Z-score
+        * logrank (float) : fitted logrank_test model
+        * labx (list) : Class labels
+        * uilabx (list) : Unique Class labels
+        * time_event (float) : Time to event
+        * censoring (bool) : Censored or not
 
     Example
     ----------
-    import kaplanmeier as km
-    df= km.example_data()
-    out=km.fit(df['time'], df['Died'], df['group'])
-    km.plot(out)
-
-    km.plot(out, cmap='Set1', cii_lines=True, cii_alpha=0.05)
-    km.plot(out, cmap=[(1, 0, 0),(0, 0, 1)])
-    km.plot(out, cmap='Set1', methodtype='custom')
-
-    out['logrank_P']
-    out['logrank_Z']
+    >>> # Import library
+    >>> import kaplanmeier as km
+    >>>
+    >>> # Example data
+    >>> df = km.example_data()
+    >>>
+    >>> # Fit
+    >>> results = km.fit(df['time'], df['Died'], df['group'])
+    >>>
+    >>> # Plot
+    >>> km.plot(results)
+    >>>
+    >>> km.plot(out, cmap='Set1', cii_lines=True, cii_alpha=0.05)
+    >>> km.plot(out, cmap=[(1, 0, 0),(0, 0, 1)])
+    >>> km.plot(out, cmap='Set1', methodtype='custom')
+    >>>
+    >>> results['logrank_P']
+    >>> results['logrank_Z']
 
     """
     if 'pandas' in str(type(time_event)):
@@ -186,28 +200,7 @@ def plot(out, fontsize=12, savepath='', width=10, height=6, cmap='Set1', cii_alp
             # Store
             kmf_all.append(kmf.fit(out['time_event'][idx], event_observed=out['censoring'][idx], label=classlabel[i], ci_labels=None, alpha=(1 - cii_alpha)))
 
-        if len(kmf_all)==1:
-            add_at_risk_counts(kmf_all[0], ax=ax)
-        elif len(kmf_all)==2:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], ax=ax)
-        elif len(kmf_all)==3:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], ax=ax)
-        elif len(kmf_all)==4:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], ax=ax)
-        elif len(kmf_all)==5:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], kmf_all[4], ax=ax)
-        elif len(kmf_all)==6:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], kmf_all[4], kmf_all[5], ax=ax)
-        elif len(kmf_all)==7:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], kmf_all[4], kmf_all[5], kmf_all[6], ax=ax)
-        elif len(kmf_all)==8:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], kmf_all[4], kmf_all[5], kmf_all[6], kmf_all[7], ax=ax)
-        elif len(kmf_all)==9:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], kmf_all[4], kmf_all[5], kmf_all[6], kmf_all[7], kmf_all[8], ax=ax)
-        elif len(kmf_all)==10:
-            add_at_risk_counts(kmf_all[0], kmf_all[1], kmf_all[2], kmf_all[3], kmf_all[4], kmf_all[5], kmf_all[6], kmf_all[7], kmf_all[8], kmf_all[9], ax=ax)
-        else:
-            print('[KM] Maximum of 10 classes is reached.')
+        add_at_risk_counts(*kmf_all, ax=ax)
 
         ax.tick_params(axis='x', length=15, width=1, direction='out', labelsize=Param['fontsize'])
         ax.tick_params(axis='y', length=15, width=1, direction='out', labelsize=Param['fontsize'])
